@@ -2,5 +2,5 @@ from django.conf.urls.defaults import patterns
 
 
 urlpatterns = patterns('',
-        (r'^$', 'contactus.views.index'),
+        (r'^$', 'vanda.apps.contactus.views.index'),
 )
